@@ -91,10 +91,13 @@ class LogPlayerKill(Event):
         self.dbno_id = self._data.get('dBNOId')
         self.damage_type_category = self._data.get('damageTypeCategory')
         self.damage_causer_name = self._data.get('damageCauserName')
-        self.damage_causer_additional_info = self._data.get('damageCauserAdditionalInfo', [])
+        self.damage_causer_additional_info = self._data.get(
+            'damageCauserAdditionalInfo', [])
         self.damage_reason = self._data.get('damageReason')
         self.distance = self._data.get('distance')
-        self.victim_game_result = objects.GameResult(self._data.get('victimGameResult', {}))
+        self.victim_game_result = objects.GameResult(
+            self._data.get('victimGameResult', {}))
+
 
 class LogParachuteLanding(Event):
 
@@ -115,12 +118,15 @@ class LogItem(Event):
 class LogItemPickup(LogItem):
     pass
 
+
 class LogItemDrop(LogItem):
     pass
 
+
 class LogItemEquip(LogItem):
     pass
 
+
 class LogItemUnequip(LogItem):
     pass
 
@@ -128,6 +134,7 @@ class LogItemUnequip(LogItem):
 class LogItemUse(LogItem):
     pass
 
+
 class LogItemBundle(Event):
 
     def from_dict(self):
@@ -140,9 +147,11 @@ class LogItemBundle(Event):
 class LogItemAttach(LogItemBundle):
     pass
 
+
 class LogItemDetach(LogItemBundle):
     pass
 
+
 class LogItemPickupFromCarepackage(LogItemPickup):
 
     def from_dict(self):
@@ -171,7 +180,8 @@ class LogObjectDestroy(Event):
         super().from_dict()
         self.character = objects.Character(self._data.get('character', {}))
         self.object_type = self._data.get('objectType')
-        self.object_location = objects.Location(self._data.get('objectLocation', {}))
+        self.object_location = objects.Location(
+            self._data.get('objectLocation', {}))
 
 
 class LogVaultStart(Event):
@@ -228,9 +238,11 @@ class LogCarePackageEvent(Event):
 class LogCarePackageSpawn(LogCarePackageEvent):
     pass
 
+
 class LogCarePackageLand(LogCarePackageEvent):
     pass
 
+
 class LogMatchDefinition(Event):
 
     def from_dict(self):
@@ -265,23 +277,28 @@ class LogMatchStart(LogMatchEvent):
         self.team_size = self._data.get('teamSize')
         self.weather_id = self._data.get('weatherId')
 
+
 class LogMatchEnd(LogMatchEvent):
     pass
 
+
 class LogGameStatePeriodic(Event):
 
     def from_dict(self):
         super().from_dict()
         self.game_state = objects.GameState(self._data.get('gameState', {}))
 
+
 class LogSwim(Event):
 
     def from_dict(self):
         super().from_dict()
         self.character = objects.Character(self._data.get('character', {}))
 
+
 class LogSwimStart(LogSwim):
-    pass        
+    pass
+
 
 class LogSwimEnd(LogSwim):
 
@@ -303,7 +320,7 @@ class LogArmorDestroy(Event):
         self.damage_causer_name = self._data.get('damageCauserName')
         self.item = objects.Item(self._data.get('item', {}))
         self.distance = self._data.get('distance')
-        
+
         # NOTE: Looking at the documentation is this still in the API?
         self.vehicle = objects.Vehicle(self._data.get('vehicle', {}))
 
@@ -329,7 +346,8 @@ class LogPlayerMakeGroggy(Event):
         self.damage_reason = self._data.get('damageReason')
         self.damage_type_category = self._data.get('damageTypeCategory')
         self.damage_causer_name = self._data.get('damageCauserName')
-        self.damage_causer_additional_info = self._data.get('damageCauserAdditionalInfo', [])
+        self.damage_causer_additional_info = self._data.get(
+            'damageCauserAdditionalInfo', [])
         self.distance = self._data.get('distance')
         self.is_attacker_in_vehicle = self._data.get('isAttackerInVehicle')
         self.dbno_id = self._data.get('dBNOId')
